# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class ActorSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'num_total_actors': 'int',
        'num_dependencies_unready_actors': 'int',
        'num_pending_creation_actors': 'int',
        'num_alive_actors': 'int',
        'num_restarting_actors': 'int',
        'num_dead_actors': 'int'
    }

    attribute_map = {
        'num_total_actors': 'num_total_actors',
        'num_dependencies_unready_actors': 'num_dependencies_unready_actors',
        'num_pending_creation_actors': 'num_pending_creation_actors',
        'num_alive_actors': 'num_alive_actors',
        'num_restarting_actors': 'num_restarting_actors',
        'num_dead_actors': 'num_dead_actors'
    }

    def __init__(self, num_total_actors=None, num_dependencies_unready_actors=None, num_pending_creation_actors=None, num_alive_actors=None, num_restarting_actors=None, num_dead_actors=None, local_vars_configuration=None):  # noqa: E501
        """ActorSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._num_total_actors = None
        self._num_dependencies_unready_actors = None
        self._num_pending_creation_actors = None
        self._num_alive_actors = None
        self._num_restarting_actors = None
        self._num_dead_actors = None
        self.discriminator = None

        self.num_total_actors = num_total_actors
        self.num_dependencies_unready_actors = num_dependencies_unready_actors
        self.num_pending_creation_actors = num_pending_creation_actors
        self.num_alive_actors = num_alive_actors
        self.num_restarting_actors = num_restarting_actors
        self.num_dead_actors = num_dead_actors

    @property
    def num_total_actors(self):
        """Gets the num_total_actors of this ActorSummary.  # noqa: E501


        :return: The num_total_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_total_actors

    @num_total_actors.setter
    def num_total_actors(self, num_total_actors):
        """Sets the num_total_actors of this ActorSummary.


        :param num_total_actors: The num_total_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_total_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_total_actors`, must not be `None`")  # noqa: E501

        self._num_total_actors = num_total_actors

    @property
    def num_dependencies_unready_actors(self):
        """Gets the num_dependencies_unready_actors of this ActorSummary.  # noqa: E501


        :return: The num_dependencies_unready_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_dependencies_unready_actors

    @num_dependencies_unready_actors.setter
    def num_dependencies_unready_actors(self, num_dependencies_unready_actors):
        """Sets the num_dependencies_unready_actors of this ActorSummary.


        :param num_dependencies_unready_actors: The num_dependencies_unready_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_dependencies_unready_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_dependencies_unready_actors`, must not be `None`")  # noqa: E501

        self._num_dependencies_unready_actors = num_dependencies_unready_actors

    @property
    def num_pending_creation_actors(self):
        """Gets the num_pending_creation_actors of this ActorSummary.  # noqa: E501


        :return: The num_pending_creation_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_pending_creation_actors

    @num_pending_creation_actors.setter
    def num_pending_creation_actors(self, num_pending_creation_actors):
        """Sets the num_pending_creation_actors of this ActorSummary.


        :param num_pending_creation_actors: The num_pending_creation_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_pending_creation_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_pending_creation_actors`, must not be `None`")  # noqa: E501

        self._num_pending_creation_actors = num_pending_creation_actors

    @property
    def num_alive_actors(self):
        """Gets the num_alive_actors of this ActorSummary.  # noqa: E501


        :return: The num_alive_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_alive_actors

    @num_alive_actors.setter
    def num_alive_actors(self, num_alive_actors):
        """Sets the num_alive_actors of this ActorSummary.


        :param num_alive_actors: The num_alive_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_alive_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_alive_actors`, must not be `None`")  # noqa: E501

        self._num_alive_actors = num_alive_actors

    @property
    def num_restarting_actors(self):
        """Gets the num_restarting_actors of this ActorSummary.  # noqa: E501


        :return: The num_restarting_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_restarting_actors

    @num_restarting_actors.setter
    def num_restarting_actors(self, num_restarting_actors):
        """Sets the num_restarting_actors of this ActorSummary.


        :param num_restarting_actors: The num_restarting_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_restarting_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_restarting_actors`, must not be `None`")  # noqa: E501

        self._num_restarting_actors = num_restarting_actors

    @property
    def num_dead_actors(self):
        """Gets the num_dead_actors of this ActorSummary.  # noqa: E501


        :return: The num_dead_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_dead_actors

    @num_dead_actors.setter
    def num_dead_actors(self, num_dead_actors):
        """Sets the num_dead_actors of this ActorSummary.


        :param num_dead_actors: The num_dead_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_dead_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_dead_actors`, must not be `None`")  # noqa: E501

        self._num_dead_actors = num_dead_actors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActorSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ActorSummary):
            return True

        return self.to_dict() != other.to_dict()
