# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class SchedulerInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'requests': 'list[RequestStateInfo]',
        'machines': 'list[MachineStateInfo]',
        'recent_launch_failures': 'list[MachineLaunchFailure]'
    }

    attribute_map = {
        'requests': 'requests',
        'machines': 'machines',
        'recent_launch_failures': 'recent_launch_failures'
    }

    def __init__(self, requests=None, machines=None, recent_launch_failures=None, local_vars_configuration=None):  # noqa: E501
        """SchedulerInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._requests = None
        self._machines = None
        self._recent_launch_failures = None
        self.discriminator = None

        self.requests = requests
        self.machines = machines
        self.recent_launch_failures = recent_launch_failures

    @property
    def requests(self):
        """Gets the requests of this SchedulerInfo.  # noqa: E501

        Current request states.  # noqa: E501

        :return: The requests of this SchedulerInfo.  # noqa: E501
        :rtype: list[RequestStateInfo]
        """
        return self._requests

    @requests.setter
    def requests(self, requests):
        """Sets the requests of this SchedulerInfo.

        Current request states.  # noqa: E501

        :param requests: The requests of this SchedulerInfo.  # noqa: E501
        :type: list[RequestStateInfo]
        """
        if self.local_vars_configuration.client_side_validation and requests is None:  # noqa: E501
            raise ValueError("Invalid value for `requests`, must not be `None`")  # noqa: E501

        self._requests = requests

    @property
    def machines(self):
        """Gets the machines of this SchedulerInfo.  # noqa: E501

        Current machine states.  # noqa: E501

        :return: The machines of this SchedulerInfo.  # noqa: E501
        :rtype: list[MachineStateInfo]
        """
        return self._machines

    @machines.setter
    def machines(self, machines):
        """Sets the machines of this SchedulerInfo.

        Current machine states.  # noqa: E501

        :param machines: The machines of this SchedulerInfo.  # noqa: E501
        :type: list[MachineStateInfo]
        """
        if self.local_vars_configuration.client_side_validation and machines is None:  # noqa: E501
            raise ValueError("Invalid value for `machines`, must not be `None`")  # noqa: E501

        self._machines = machines

    @property
    def recent_launch_failures(self):
        """Gets the recent_launch_failures of this SchedulerInfo.  # noqa: E501

        Recent launch failures.  # noqa: E501

        :return: The recent_launch_failures of this SchedulerInfo.  # noqa: E501
        :rtype: list[MachineLaunchFailure]
        """
        return self._recent_launch_failures

    @recent_launch_failures.setter
    def recent_launch_failures(self, recent_launch_failures):
        """Sets the recent_launch_failures of this SchedulerInfo.

        Recent launch failures.  # noqa: E501

        :param recent_launch_failures: The recent_launch_failures of this SchedulerInfo.  # noqa: E501
        :type: list[MachineLaunchFailure]
        """
        if self.local_vars_configuration.client_side_validation and recent_launch_failures is None:  # noqa: E501
            raise ValueError("Invalid value for `recent_launch_failures`, must not be `None`")  # noqa: E501

        self._recent_launch_failures = recent_launch_failures

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchedulerInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SchedulerInfo):
            return True

        return self.to_dict() != other.to_dict()
